### R code from vignette source 'profdpm.Rnw'

###################################################
### code chunk number 1: profdpm.Rnw:246-248
###################################################
options(prompt = "R> ")
options(continue = "R+ ")


###################################################
### code chunk number 2: profdpm.Rnw:250-262
###################################################
set.seed(42)

sim <- function(slope.multiplier = 1) {
    x <- as.matrix(runif(99))
    s <- slope.multiplier * c(-10,0,10)
    y <- c(s[1]*x[1:33], s[2]*x[34:66], s[3]*x[67:99]) + rnorm(99)
    group <- rep(1:33, rep(3,33))
    return(data.frame(x=x,y=y,group=group))
}
dat <- sim()
library("profdpm")
fitL <- profLinear(y ~ 0 + x, group=group, data=dat)


###################################################
### code chunk number 3: figSim1
###################################################
sfitL <- summary(fitL)
plot(dat$x, dat$y, col=grey(0.9), xlab='x', ylab='y')
for(grp in unique(dat$group)) {
    ind <- which(dat$group==grp)
    ord <- order(dat$x[ind])
    lines(dat$x[ind][ord], dat$y[ind][ord], col=grey(0.9))
}
for(cls in 1:length(sfitL)) {
    abline(a=0,b=sfitL[[cls]]$sum$est[1], col=cls, lty=2)
    abline(a=0,b=sfitL[[cls]]$sum$low[1], col=cls)
    abline(a=0,b=sfitL[[cls]]$sum$upp[1], col=cls)
}


###################################################
### code chunk number 4: profdpm.Rnw:285-286
###################################################
sfitL <- summary(fitL)
plot(dat$x, dat$y, col=grey(0.9), xlab='x', ylab='y')
for(grp in unique(dat$group)) {
    ind <- which(dat$group==grp)
    ord <- order(dat$x[ind])
    lines(dat$x[ind][ord], dat$y[ind][ord], col=grey(0.9))
}
for(cls in 1:length(sfitL)) {
    abline(a=0,b=sfitL[[cls]]$sum$est[1], col=cls, lty=2)
    abline(a=0,b=sfitL[[cls]]$sum$low[1], col=cls)
    abline(a=0,b=sfitL[[cls]]$sum$upp[1], col=cls)
}


###################################################
### code chunk number 5: profdpm.Rnw:301-304
###################################################
simulatedPartL <- rep(1:3, rep(33,3))
estimatedPartL <- fitL$clust
pci(simulatedPartL, estimatedPartL)


###################################################
### code chunk number 6: figSim2
###################################################
mult <- rep(seq(1, 0.01, length.out=33), 10)
Rand <- sapply(mult, function(mult) {
    dat <- sim(mult)
    fit <- profLinear(y ~ 0 + x, group=group, data=dat)
    pci(rep(1:3, rep(33,3)), fit$clust)['R']
})
lws <- lowess(x=mult,y=Rand)
plot(lws$x, lws$y, type='l',
     xlab='slope multiplier', ylab='Rand index')
points(mult + rnorm(length(mult),0,1/200),
     Rand + rnorm(length(Rand),0,1/200), col=grey(0.9))


###################################################
### code chunk number 7: profdpm.Rnw:331-332
###################################################
mult <- rep(seq(1, 0.01, length.out=33), 10)
Rand <- sapply(mult, function(mult) {
    dat <- sim(mult)
    fit <- profLinear(y ~ 0 + x, group=group, data=dat)
    pci(rep(1:3, rep(33,3)), fit$clust)['R']
})
lws <- lowess(x=mult,y=Rand)
plot(lws$x, lws$y, type='l',
     xlab='slope multiplier', ylab='Rand index')
points(mult + rnorm(length(mult),0,1/200),
     Rand + rnorm(length(Rand),0,1/200), col=grey(0.9))


###################################################
### code chunk number 8: profdpm.Rnw:351-356
###################################################
p <- seq(0.9,0.1,length.out=9)
y1 <- matrix(rbinom(999, 1, p), 111, 9, TRUE)
y2 <- matrix(rbinom(999, 1, rev(p)), 111, 9, TRUE)
dat <- as.data.frame(rbind(y1, y2))
fitb <- profBinary(~0+., data=dat)


###################################################
### code chunk number 9: figSim3
###################################################
alpha <- 10^(-seq(0, 40, length.out=33))
Rand <- sapply(alpha, function(alpha) {
    fit <- profBinary(~0+., data=dat, param=list(alpha=alpha))
    pci(rep(1:2, rep(111,2)), fit$clust)['R']
})
lws <- lowess(x=log(alpha),y=Rand)
plot(lws$x, lws$y, type='l',
     xlab=expression(paste('log', alpha)),
     ylab='Rand index')

points(log(alpha), Rand + rnorm(length(Rand),0,1/200),
     col=grey(0.9))


###################################################
### code chunk number 10: profdpm.Rnw:383-384
###################################################
alpha <- 10^(-seq(0, 40, length.out=33))
Rand <- sapply(alpha, function(alpha) {
    fit <- profBinary(~0+., data=dat, param=list(alpha=alpha))
    pci(rep(1:2, rep(111,2)), fit$clust)['R']
})
lws <- lowess(x=log(alpha),y=Rand)
plot(lws$x, lws$y, type='l',
     xlab=expression(paste('log', alpha)),
     ylab='Rand index')

points(log(alpha), Rand + rnorm(length(Rand),0,1/200),
     col=grey(0.9))


